@@ -90,7 +90,7 @@ class PythonPackageToxEnv(Python, PackageToxEnv, ABC):
             # c-extension codes are trickier, but as of today both poetry/setuptools uses pypa/wheels logic
             # https://github.com/pypa/wheel/blob/master/src/wheel/bdist_wheel.py#L234-L280
             try:
-                run_py = cast(Python, run_env).base_python
+                run_py = cast("Python", run_env).base_python
             except NoInterpreter:
                 run_py = None
 
@@ -116,11 +116,16 @@ class PythonPackageToxEnv(Python, PackageToxEnv, ABC):
         )
         pkg_env = run_env.conf["wheel_build_env"]
         result = yield pkg_env, run_env.conf["package_tox_env_type"]
-        self._wheel_build_envs[pkg_env] = cast(PythonPackageToxEnv, result)
+        self._wheel_build_envs[pkg_env] = cast("PythonPackageToxEnv", result)
 
     def child_pkg_envs(self, run_conf: EnvConfigSet) -> Iterator[PackageToxEnv]:
         if run_conf["package"] == "wheel":
-            env = self._wheel_build_envs.get(run_conf["wheel_build_env"])
+            try:
+                conf = run_conf["wheel_build_env"]
+            except Skip:
+                # the __getitem__ method might raise Skip if the interpreter is not available
+                return
+            env = self._wheel_build_envs.get(conf)
             if env is not None and env.name != self.name:
                 yield env
 
