@@ -1,29 +1,34 @@
-"""
-Declare the abstract base class for tox environments that handle the Python language via the virtualenv project.
-"""
+"""Declare the abstract base class for tox environments that handle the Python language via the virtualenv project."""
+
 from __future__ import annotations
 
 import os
 import sys
+from abc import ABC
 from pathlib import Path
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from virtualenv import __version__ as virtualenv_version
-from virtualenv import session_via_cli
-from virtualenv.create.creator import Creator
-from virtualenv.run.session import Session
+from virtualenv import app_data, session_via_cli
+from virtualenv.discovery import cached_py_info
+from virtualenv.discovery.py_spec import PythonSpec
 
 from tox.config.loader.str_convert import StrConvert
-from tox.execute.api import Execute
 from tox.execute.local_sub_process import LocalSubProcessExecutor
+from tox.tox_env.python.api import Python, PythonInfo
 from tox.tox_env.python.pip.pip_install import Pip
 
-from ...api import ToxEnvCreateArgs
-from ..api import Python, PythonInfo
+if TYPE_CHECKING:
+    from virtualenv.create.creator import Creator
+    from virtualenv.discovery.py_info import PythonInfo as VirtualenvPythonInfo
+    from virtualenv.run.session import Session
+
+    from tox.execute.api import Execute
+    from tox.tox_env.api import ToxEnvCreateArgs
 
 
-class VirtualEnv(Python):
-    """A python executor that uses the virtualenv project with pip"""
+class VirtualEnv(Python, ABC):
+    """A python executor that uses the virtualenv project with pip."""
 
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
         self._virtualenv_session: Session | None = None
@@ -36,7 +41,7 @@ class VirtualEnv(Python):
         self.conf.add_config(
             keys=["system_site_packages", "sitepackages"],
             of_type=bool,
-            default=lambda conf, name: StrConvert().to_bool(  # noqa: U100
+            default=lambda conf, name: StrConvert().to_bool(  # noqa: ARG005
                 self.environment_variables.get("VIRTUALENV_SYSTEM_SITE_PACKAGES", "False"),
             ),
             desc="create virtual environments that also have access to globally installed packages.",
@@ -44,7 +49,7 @@ class VirtualEnv(Python):
         self.conf.add_config(
             keys=["always_copy", "alwayscopy"],
             of_type=bool,
-            default=lambda conf, name: StrConvert().to_bool(  # noqa: U100
+            default=lambda conf, name: StrConvert().to_bool(  # noqa: ARG005
                 self.environment_variables.get(
                     "VIRTUALENV_COPIES",
                     self.environment_variables.get("VIRTUALENV_ALWAYS_COPY", "False"),
@@ -55,7 +60,7 @@ class VirtualEnv(Python):
         self.conf.add_config(
             keys=["download"],
             of_type=bool,
-            default=lambda conf, name: StrConvert().to_bool(  # noqa: U100
+            default=lambda conf, name: StrConvert().to_bool(  # noqa: ARG005
                 self.environment_variables.get("VIRTUALENV_DOWNLOAD", "False"),
             ),
             desc="true if you want virtualenv to upgrade pip/wheel/setuptools to the latest version",
@@ -112,10 +117,9 @@ class VirtualEnv(Python):
         base_python: list[str] = self.conf["base_python"]
         if "VIRTUALENV_NO_PERIODIC_UPDATE" not in env:
             env["VIRTUALENV_NO_PERIODIC_UPDATE"] = "True"
-        site = getattr(self.options, "site_packages", False) or self.conf["system_site_packages"]
         env["VIRTUALENV_CLEAR"] = "False"
-        env["VIRTUALENV_SYSTEM_SITE_PACKAGES"] = str(site)
-        env["VIRTUALENV_COPIES"] = str(getattr(self.options, "always_copy", False) or self.conf["always_copy"])
+        env["VIRTUALENV_SYSTEM_SITE_PACKAGES"] = str(self.conf["system_site_packages"])
+        env["VIRTUALENV_COPIES"] = str(self.conf["always_copy"])
         env["VIRTUALENV_DOWNLOAD"] = str(self.conf["download"])
         env["VIRTUALENV_PYTHON"] = "\n".join(base_python)
         if hasattr(self.options, "discover"):
@@ -129,34 +133,34 @@ class VirtualEnv(Python):
     def create_python_env(self) -> None:
         self.session.run()
 
-    def _get_python(self, base_python: list[str]) -> PythonInfo | None:  # noqa: U100
+    def _get_python(self, base_python: list[str]) -> PythonInfo | None:  # noqa: ARG002
         # the base pythons are injected into the virtualenv_env_vars, so we don't need to use it here
         try:
             interpreter = self.creator.interpreter
-        except RuntimeError:  # if can't find
+        except (FileNotFoundError, RuntimeError):  # Unable to find the interpreter
             return None
         return PythonInfo(
             implementation=interpreter.implementation,
             version_info=interpreter.version_info,
             version=interpreter.version,
-            is_64=(interpreter.architecture == 64),
+            is_64=(interpreter.architecture == 64),  # noqa: PLR2004
             platform=interpreter.platform,
             extra={"executable": Path(interpreter.system_executable).resolve()},
         )
 
     def prepend_env_var_path(self) -> list[Path]:
-        """Paths to add to the executable"""
+        """Paths to add to the executable."""
         # we use the original executable as shims may be somewhere else
         return list(dict.fromkeys((self.creator.bin_dir, self.creator.script_dir)))
 
     def env_site_package_dir(self) -> Path:
-        return cast(Path, self.creator.purelib)
+        return cast("Path", self.creator.purelib)
 
     def env_python(self) -> Path:
-        return cast(Path, self.creator.exe)
+        return cast("Path", self.creator.exe)
 
     def env_bin_dir(self) -> Path:
-        return cast(Path, self.creator.script_dir)
+        return cast("Path", self.creator.script_dir)
 
     @property
     def runs_on_platform(self) -> str:
@@ -167,3 +171,30 @@ class VirtualEnv(Python):
         environment_variables = super().environment_variables
         environment_variables["VIRTUAL_ENV"] = str(self.conf["env_dir"])
         return environment_variables
+
+    @classmethod
+    def python_spec_for_path(cls, path: Path) -> PythonSpec:
+        """
+        Get the spec for an absolute path to a Python executable.
+
+        :param path: the path investigated
+        :return: the found spec
+        """
+        info = cls.get_virtualenv_py_info(path)
+        return PythonSpec.from_string_spec(
+            f"{info.implementation}{info.version_info.major}{info.version_info.minor}-{info.architecture}"
+        )
+
+    @staticmethod
+    def get_virtualenv_py_info(path: Path) -> VirtualenvPythonInfo:
+        """
+        Get the version info for an absolute path to a Python executable.
+
+        :param path: the path investigated
+        :return: the found information (cached)
+        """
+        return cached_py_info.from_exe(
+            cached_py_info.PythonInfo,
+            app_data.make_app_data(None, read_only=False, env=os.environ),
+            str(path),
+        )
