@@ -31,6 +31,7 @@ def test_verbose_no_test() -> None:
         "verbose": 4,
         "quiet": 0,
         "colored": "no",
+        "stderr_color": "RED",
         "work_dir": None,
         "root_dir": None,
         "config_file": None,
@@ -84,16 +85,18 @@ def test_env_var_exhaustive_parallel_values(
     monkeypatch.setenv("TOX_PARALLEL", "3")
     monkeypatch.setenv("TOX_PARALLEL_LIVE", "no")
     monkeypatch.setenv("TOX_OVERRIDE", "a=b;c=d")
+    monkeypatch.setenv("TOX_DISCOVER", "/foo/bar;/bar/baz;/baz/foo")
 
     options = get_options()
     assert vars(options.parsed) == {
         "always_copy": False,
         "colored": "no",
+        "stderr_color": "RED",
         "command": "legacy",
         "default_runner": "virtualenv",
         "develop": False,
         "devenv_path": None,
-        "discover": [],
+        "discover": ["/foo/bar", "/bar/baz", "/baz/foo"],
         "env": CliEnv(["py37", "py36"]),
         "force_dep": [],
         "hash_seed": ANY,
