@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 from unittest.mock import ANY
 
 import pytest
@@ -51,10 +51,15 @@ def test_set_env_bad_line() -> None:
         SetEnv("A", "py", "py", Path())
 
 
+ConfigFileFormat = Literal["ini", "toml"]
+
+
 class EvalSetEnv(Protocol):
     def __call__(
         self,
-        tox_ini: str,
+        config: str,
+        *,
+        of_type: ConfigFileFormat = "ini",
         extra_files: dict[str, Any] | None = ...,
         from_cwd: Path | None = ...,
     ) -> SetEnv: ...
@@ -62,8 +67,14 @@ class EvalSetEnv(Protocol):
 
 @pytest.fixture
 def eval_set_env(tox_project: ToxProjectCreator) -> EvalSetEnv:
-    def func(tox_ini: str, extra_files: dict[str, Any] | None = None, from_cwd: Path | None = None) -> SetEnv:
-        prj = tox_project({"tox.ini": tox_ini, **(extra_files or {})})
+    def func(
+        config: str,
+        *,
+        of_type: ConfigFileFormat = "ini",
+        extra_files: dict[str, Any] | None = None,
+        from_cwd: Path | None = None,
+    ) -> SetEnv:
+        prj = tox_project({f"tox.{of_type}": config, **(extra_files or {})})
         result = prj.run("c", "-k", "set_env", "-e", "py", from_cwd=None if from_cwd is None else prj.path / from_cwd)
         result.assert_success()
         set_env: SetEnv = result.env_conf("py")["set_env"]
@@ -120,7 +131,7 @@ def test_set_env_tty_off(eval_set_env: EvalSetEnv, mocker: MockerFixture) -> Non
 
 def test_set_env_circular_use_os_environ(tox_project: ToxProjectCreator) -> None:
     prj = tox_project({"tox.ini": "[testenv]\npackage=skip\nset_env=a={env:b}\n b={env:a}"})
-    result = prj.run("c", "-e", "py")
+    result = prj.run("c", "-e", "py", raise_on_config_fail=False)
     result.assert_success()
     assert "replace failed in py.set_env with MatchRecursionError" in result.out, result.out
     assert "circular chain between set env a, b" in result.out, result.out
@@ -149,7 +160,20 @@ def test_set_env_honor_override(eval_set_env: EvalSetEnv) -> None:
     assert set_env.load("PIP_DISABLE_PIP_VERSION_CHECK") == "0"
 
 
-def test_set_env_environment_file(eval_set_env: EvalSetEnv) -> None:
+@pytest.mark.parametrize(
+    ("of_type", "config"),
+    [
+        pytest.param("ini", "[testenv]\npackage=skip\nset_env=file|A{/}a.txt\nchange_dir=C", id="ini"),
+        pytest.param("toml", '[env_run_base]\npackage="skip"\nset_env={file="A{/}a.txt"}\nchange_dir="C"', id="toml"),
+        pytest.param("ini", "[testenv]\npackage=skip\nset_env=file|{env:env_file}\nchange_dir=C", id="ini-env"),
+        pytest.param(
+            "toml", '[env_run_base]\npackage="skip"\nset_env={file="{env:env_file}"}\nchange_dir="C"', id="toml-env"
+        ),
+    ],
+)
+def test_set_env_environment_file(
+    of_type: ConfigFileFormat, config: str, eval_set_env: EvalSetEnv, monkeypatch: MonkeyPatch
+) -> None:
     env_file = """
     A=1
     B= 2
@@ -158,9 +182,10 @@ def test_set_env_environment_file(eval_set_env: EvalSetEnv) -> None:
     E = "1"
     F =
     """
+    monkeypatch.setenv("env_file", "A{/}a.txt")
+
     extra = {"A": {"a.txt": env_file}, "B": None, "C": None}
-    ini = "[testenv]\npackage=skip\nset_env=file|A{/}a.txt\nchange_dir=C"
-    set_env = eval_set_env(ini, extra_files=extra, from_cwd=Path("B"))
+    set_env = eval_set_env(config, of_type=of_type, extra_files=extra, from_cwd=Path("B"))
     content = {k: set_env.load(k) for k in set_env}
     assert content == {
         "PIP_DISABLE_PIP_VERSION_CHECK": "1",
@@ -174,6 +199,42 @@ def test_set_env_environment_file(eval_set_env: EvalSetEnv) -> None:
     }
 
 
+@pytest.mark.parametrize(
+    ("of_type", "config"),
+    [
+        pytest.param("ini", "[testenv]\npackage=skip\nset_env=file|A{/}a.txt\n X=y\nchange_dir=C", id="ini"),
+        pytest.param(
+            "toml", '[env_run_base]\npackage="skip"\nset_env={file="A{/}a.txt", X="y"}\nchange_dir="C"', id="toml"
+        ),
+        pytest.param("ini", "[testenv]\npackage=skip\nset_env=file|{env:env_file}\n X=y\nchange_dir=C", id="ini-env"),
+        pytest.param(
+            "toml",
+            '[env_run_base]\npackage="skip"\nset_env={file="{env:env_file}", X="y"}\nchange_dir="C"',
+            id="toml-env",
+        ),
+    ],
+)
+def test_set_env_environment_file_combined_with_normal_setting(
+    of_type: ConfigFileFormat, config: str, eval_set_env: EvalSetEnv, monkeypatch: MonkeyPatch
+) -> None:
+    env_file = """
+    A=1
+    """
+    # Monkeypatch only used for some of the parameters
+    monkeypatch.setenv("env_file", "A{/}a.txt")
+
+    extra = {"A": {"a.txt": env_file}, "B": None, "C": None}
+    set_env = eval_set_env(config, of_type=of_type, extra_files=extra, from_cwd=Path("B"))
+    content = {k: set_env.load(k) for k in set_env}
+    assert content == {
+        "PIP_DISABLE_PIP_VERSION_CHECK": "1",
+        "PYTHONHASHSEED": ANY,
+        "A": "1",
+        "X": "y",
+        "PYTHONIOENCODING": "utf-8",
+    }
+
+
 def test_set_env_environment_file_missing(tox_project: ToxProjectCreator) -> None:
     project = tox_project({"tox.ini": "[testenv]\npackage=skip\nset_env=file|magic.txt"})
     result = project.run("r")
