@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import sys
+from types import SimpleNamespace
 from typing import TYPE_CHECKING, Callable
 from unittest.mock import patch
 
@@ -103,6 +104,7 @@ def test_diff_msg_no_diff() -> None:
         ("3.10", "3.10"),
         ("3.9", "3.9"),
         ("2.7", "2.7"),
+        ("pypy-3.10", "pypy3.10"),
     ],
     ids=lambda a: "|".join(a) if isinstance(a, list) else str(a),
 )
@@ -165,7 +167,7 @@ def test_base_python_env_conflict_show_conf(tox_project: ToxProjectCreator, igno
     if ignore_conflict is not None:
         ini += f"\n[tox]\nignore_base_python_conflict={ignore_conflict}"
     project = tox_project({"tox.ini": ini})
-    result = project.run("c", "-e", f"py{py_ver}", "-k", "base_python")
+    result = project.run("c", "-e", f"py{py_ver}", "-k", "base_python", raise_on_config_fail=False)
     result.assert_success()
     if ignore_conflict:
         out = f"[testenv:py{py_ver}]\nbase_python = py{py_ver}\n"
@@ -289,3 +291,29 @@ def test_usedevelop_with_nonexistent_basepython(tox_project: ToxProjectCreator)
     project = tox_project({"tox.ini": ini})
     result = project.run()
     assert result.code == 0
+
+
+@pytest.mark.parametrize(
+    ("impl", "major", "minor", "arch"),
+    [
+        ("cpython", 3, 12, 64),
+        ("pypy", 3, 9, 32),
+    ],
+)
+def test_python_spec_for_sys_executable(impl: str, major: int, minor: int, arch: int, mocker: MockerFixture) -> None:
+    version_info = SimpleNamespace(major=major, minor=minor, micro=5, releaselevel="final", serial=0)
+    implementation = SimpleNamespace(
+        name=impl,
+        cache_tag=f"{impl}-{major}{minor}",
+        version=version_info,
+        hexversion=...,
+        _multiarch=...,
+    )
+    mocker.patch.object(sys, "version_info", version_info)
+    mocker.patch.object(sys, "implementation", implementation)
+    mocker.patch.object(sys, "maxsize", 2**arch // 2 - 1)
+    spec = Python._python_spec_for_sys_executable()  # noqa: SLF001
+    assert spec.implementation == impl
+    assert spec.major == major
+    assert spec.minor == minor
+    assert spec.architecture == arch
